from setuptools import setup

setup(name='tttDistributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['tttDistributions'],
      author = 'EmmaW',
      author_email = 'emmayt@outlook.com',
      zip_safe=False)
